==> modx-2.0.6-pl-ja.zip: modx-2.0.6-pl-ja/core/lexicon/ja/resource.inc.php <==
<?php
/**
 * Resource Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['access'] = 'アクセス';
$_lang['cache_output'] = 'キャッシュ出力';
$_lang['changes'] = '変更';
$_lang['class_key'] = 'クラスキー';
$_lang['context'] = 'コンテキスト';
$_lang['createedit_document'] = 'ドキュメントの作成・編集';
$_lang['createedit_static'] = '静的リソースの作成・編集';
$_lang['createedit_symlink'] = 'シムリンクの作成・編集';
$_lang['createedit_weblink'] = 'ウェブリンクの作成・編集';
$_lang['document'] = 'ドキュメント';
$_lang['document_create'] = 'ドキュメントを作成';
$_lang['document_create_here'] = 'ここにドキュメントを作成';
$_lang['document_new'] = '新しいドキュメント';
$_lang['documents'] = 'ドキュメント';
$_lang['duplicate_alias_found'] = 'リソース [[+id]] はすでにエイリアス [[+alias]] を使用しています。重複しないエイリアス名を入力してください。';
$_lang['empty_template'] = '(空)';
$_lang['general'] = '一般';
$_lang['markup'] = 'マークアップ/構造';
$_lang['none'] = 'なし';
$_lang['page_settings'] = 'ページ設定';
$_lang['preview'] = 'プレビュー';
$_lang['resource_access_message'] = 'このリソースが属するリソースグループを設定できます。';
$_lang['resource_add_children_access_denied'] = '現在のアカウントにはここにリソースを作成する権限がありません。';
$_lang['resource_alias'] = 'エイリアス';
$_lang['resource_alias_help'] = 'このリソースの別名。この名前はURL表現にも使用されます。<br /><br />http://example.com/alias<br /><br />フレンドリーURL設定が有効な場合のみ動作します。';
$_lang['resource_change_template_confirm'] = 'このテンプレートを変更しますか？';
$_lang['resource_cacheable'] = 'キャッシュ有効';
$_lang['resource_cacheable_help'] = '有効にすると、リソースはキャッシュに保存されます。';
$_lang['resource_cancel_dirty_confirm'] = '未確定の変更があります。本当にキャンセルしますか？';
$_lang['resource_class_key_help'] = 'これはリソースのクラスキーです。MODxのタイプで表示します。';
$_lang['resource_content'] = 'リソースコンテンツ';
$_lang['resource_contentdispo'] = 'コンテンツの渡し方';
$_lang['resource_contentdispo_help'] = 'このの項目を使用して、このリソースがブラウザでどのように扱われるかを指定します。「Attachment」を選択するとファイルのダウンロードとみなします。';
$_lang['resource_content_type'] = 'コンテンツタイプ';
$_lang['resource_content_type_help'] = 'このリソースのコンテンツタイプを設定します。どのコンテンツタイプを選択すればよいかが分からない場合は、「text/html」のままにして下さい。';
$_lang['resource_create_access_denied'] = '現在のアカウントにはリソースを作成する権限がありません。';
$_lang['resource_create_here'] = 'ここにリソースを作成する';
$_lang['resource_createdby'] = '作成者';
$_lang['resource_createdon'] = '作成日';
$_lang['resource_delete'] = '削除する';
$_lang['resource_delete_confirm'] = '本当にこのリソースを削除しますか？<br />サブリソースも同時に削除されます。';
$_lang['resource_description'] = '説明(Description)';
$_lang['resource_description_help'] = 'リソースの説明。検索エンジン対策などに。[[*description]]として呼び出します。';
$_lang['resource_duplicate'] = '複製を作る';
$_lang['resource_duplicate_confirm'] = '本当にこのリソースを複製しますか？サブリソースも複製されます。';
$_lang['resource_edit'] = '編集する';
$_lang['resource_editedby'] = '編集者';
$_lang['resource_editedon'] = '編集日';
$_lang['resource_err_change_parent_to_folder'] = 'リソースの親フォルダを変更中にエラーが発生しました。';
$_lang['resource_err_class'] = 'リソースは有効な [[+class]] ではありません。';
$_lang['resource_err_create'] = 'リソースの作成中にエラーが発生しました。';
$_lang['resource_err_delete'] = 'リソースの削除中にエラーが発生しました。';
$_lang['resource_err_delete_children'] = 'サブリソースを削除中にエラーが発生しました。';
$_lang['resource_err_delete_container_sitestart'] = '削除しようとしているリソースは、リソース [[+id]] を含むコンテナです。このリソースは「サイトスタート」として登録されているため、削除できません。他のリソースを「サイトスタート」に設定してからリトライしてください。';
$_lang['resource_err_delete_container_siteunavailable'] = '削除しようとしているリソースはリソース [[+id]] を含むフォルダーです。このリソースは、「メンテナンスモード用ページ」として登録されているため、削除できません。他のリソースを「メンテナンスモード用ページ」に設定してからリトライしてください。';
$_lang['resource_err_delete_sitestart'] = '「サイトスタート」のリソースであるため、削除できません';
$_lang['resource_err_delete_siteunavailable'] = '「メンテナンスモード用ページとして使用されているため、削除できません';
$_lang['resource_err_duplicate'] = 'リソースを複製中にエラーが発生しました。';
$_lang['resource_err_move_to_child'] = '自身のサブリソースには移動できません。';
$_lang['resource_err_nf'] = 'リソースが見つかりませんでした。';
$_lang['resource_err_nfs'] = 'ID [[+id]] のリソースが見つかりません。';
$_lang['resource_err_ns'] = 'リソースが指定されていません。';
$_lang['resource_err_own_parent'] = 'リソースは自身の親にはなれません。';
$_lang['resource_err_publish'] = 'リソースの公開開始日時設定中にエラーが発生しました。';
$_lang['resource_err_new_parent_nf'] = 'ID [[+id]] の親リソースが見つかりません。';
$_lang['resource_err_remove'] = 'リソースの削除中にエラーが発生しました。';
$_lang['resource_err_save'] = 'リソースの保存中にエラーが発生しました。';
$_lang['resource_err_select_parent'] = '親リソースを選択して下さい。';
$_lang['resource_err_undelete'] = 'リソースの復活中にエラーが発生しました。';
$_lang['resource_err_undelete_children'] = 'サブリソースを復活中にエラーが発生しました。';
$_lang['resource_err_unpublish'] = 'リソースの公開終了日時設定中にエラーが発生しました。';
$_lang['resource_err_unpublish_sitestart'] = 'このリソースはトップページ(site_start)として設定されています。非公開に設定することはできません。';
$_lang['resource_err_unpublish_sitestart_dates'] = 'リソースはサイトスタート変数にリンクされていて、公開開始・終了の日付情報を保持することはできません';
$_lang['resource_folder'] = 'コンテナ属性';
$_lang['resource_folder_help'] = 'これにチェックを入れると、リソースは他のリソースのコンテナとして機能します。「コンテナ」はフォルダのようなもので、これだけがコンテンツを持つことができます。';
$_lang['resource_group_resource_err_ae'] = 'リソースは既にそのリソースグループに含まれます。';
$_lang['resource_group_resource_err_nf'] = 'リソースはそのリソースグループに含まれません。';
$_lang['resource_hide_from_menus'] = 'メニューに表示しない';
$_lang['resource_hide_from_menus_help'] = '有効にしたとき、リソースはウェブメニューの中で有効に<b>なりません</b>。いくつかのMenuBuilderではこのオプションを無視する可能性があることに注意してください。';
$_lang['resource_link_attributes'] = 'リンク属性';
$_lang['resource_link_attributes_help'] = 'このリソースのリンクの属性を指定します。例えば target= や rel= など。';
$_lang['resource_locked_by'] = 'リソースID [[+id]] は現在 [[+user]] にロックされています。';
$_lang['resource_longtitle'] = '長いタイトル';
$_lang['resource_longtitle_help'] = '長いタイトルを指定します。[[*longtitle]]として呼び出します。';
$_lang['resource_menuindex'] = 'メニューインデックス';
$_lang['resource_menuindex_help'] = 'これは一覧の中でのリソースの順序です。それは通常、動的にリソースを表示する順序を指定するために使用されます。いくつかの設定ではこれを無視するかもしれません。';
$_lang['resource_menutitle'] = 'メニュータイトル';
$_lang['resource_menutitle_help'] = 'ナビゲーションのメニュー名に用いる想定の、短めのタイトルを指定します。[[*menutitle]]として呼び出します。';
$_lang['resource_new'] = '新しいリソース';
$_lang['resource_notcached'] = 'このリソースはまだキャッシュされていません。';
$_lang['resource_pagetitle'] = 'タイトル';
$_lang['resource_pagetitle_help'] = 'リソース名を指定します。バックスラッシュは使えません。[[*pagetitle]]として呼び出します。サイトツリーの表示が煩雑にならないよう、短めの名前をつけるとよいでしょう。長めのタイトルが必要な場合は「長いタイトル」をお使いください。';
$_lang['resource_parent'] = '親リソース';
$_lang['resource_parent_help'] = '親リソースのIDを設定します。';
$_lang['resource_parent_select_node'] = '左のリストからノードを選択して下さい。';
$_lang['resource_publish'] = '公開する';
$_lang['resource_publish_confirm'] = 'ここで公開すると、このリソースに設定されている公開日時情報が初期化されます。もし設定を維持したい場合はリソース編集画面を開いて必要に応じて編集してください。<br />続けますか？';
$_lang['resource_publishdate'] = '公開開始予定日時';
$_lang['resource_publishdate_help'] = '公開開始予定日時をセットすると、公開開始予定日時になるとすぐに公開されます。カレンダーアイコンをクリックし、日付を選択するか、自動的に公開開始されないように空白にしてください。';
$_lang['resource_published'] = '公開する';
$_lang['resource_published_help'] = '「公開する」のチェックを外すと、このリソースは非公開になります。';
$_lang['resource_publishedby'] = '公開者';
$_lang['resource_publishedon'] = '公開開始日時';
$_lang['resource_publishedon_help'] = 'リソースが公開開始された日時。';
$_lang['resource_refresh'] = 'ツリー表示を更新';
$_lang['resource_richtext'] = 'リッチテキスト';
$_lang['resource_richtext_help'] = '有効にすると、リソースの編集にリッチテキストエディタを使用できます。リソースにJavaScriptやフォームを含む場合は、リッチテキストエディタがスクリプトやタグを乱す可能性がありますので、このチェックをはずし、プレーンテキストモードで編集してください。';
$_lang['resource_searchable'] = '検索対象';
$_lang['resource_searchable_help'] = '有効にすると、リソースを検索することができます。また、この設定はスニペットで他の目的に使用することができます。';
$_lang['resource_settings'] = 'リソース設定';
$_lang['resource_status'] = 'ステータス';
$_lang['resource_status_help'] = '公開開始されている場合はリソースは保存された直後に一般の人に閲覧可能になります。それ以外の場合は、公開サイトからは見えません。';
$_lang['resource_summary'] = '要約(リード文)';
$_lang['resource_summary_help'] = 'リソースの簡単な概要。新着情報の一覧やRSSフィードなどで用いるとよいでしょう。';
$_lang['resource_syncsite'] = '更新時にキャッシュ削除';
$_lang['resource_syncsite_help'] = 'ここにチェックを入れると、リソースの保存時にキャッシュを初期化します。';
$_lang['resource_template'] = '使用テンプレート';
$_lang['resource_template_help'] = 'リソースで使用するテンプレートを設定します。';
$_lang['resource_undelete'] = '削除から復活';
$_lang['resource_unpublish'] = '非公開にする';
$_lang['resource_unpublish_confirm'] = 'ここで非公開にすると、このリソースに設定されている公開日時情報が初期化されます。もし設定を維持したい場合はリソースの編集画面を開いて必要に応じて編集してください。<br />続けますか？';
$_lang['resource_unpublishdate'] = '公開終了予定日時';
$_lang['resource_unpublishdate_help'] = '公開終了予定日時を設定すると、公開終了予定日時になるとすぐに公開が終了します。カレンダーアイコンをクリックし、日付を選択するか、自動的に公開終了にされないように空白にしてください。';
$_lang['resource_unpublished'] = '公開終了';
$_lang['resource_untitled'] = '無題のリソース';
$_lang['resource_with_id_not_found'] = 'リソースID %s が見つかりません。';
$_lang['resource_view'] = '詳細情報';
$_lang['show_sort_options'] = 'ソートオプションの表示';
$_lang['site_schedule'] = '公開状態の一覧';
$_lang['site_schedule_desc'] = '公開および公開終了の予定一覧';
$_lang['source'] = 'ソース';
$_lang['static_resource'] = '静的リソース';
$_lang['static_resource_create_here'] = 'ここに静的リソースを作成';
$_lang['static_resource_new'] = '新しい静的リソース';
$_lang['status'] = 'ステータス';
$_lang['symlink'] = 'シムリンク';
$_lang['symlink_create'] = 'シムリンクを作成';
$_lang['symlink_create_here'] = 'ここにシムリンクを作成';
$_lang['symlink_message'] = 'シムリンクは、他の任意のリソースのクローンです。クローン元の内容がそのまま表示されますが、URLはここで指定したものが反映されます。';
$_lang['symlink_new'] = '新しいシムリンク';
$_lang['template_variables'] = 'テンプレート変数';
$_lang['untitled_resource'] = '無題のリソース';
$_lang['weblink'] = 'ウェブリンク';
$_lang['weblink_create'] = 'ウェブリンクを作成';
$_lang['weblink_create_here'] = 'ここにウェブリンクを作成';
$_lang['weblink_help'] = 'このウェブリンクによって参照させたいオブジェクトのアドレスを設定します。';
$_lang['weblink_message'] = 'ウェブリンクは、インターネット上のあらゆるオブジェクトに対するショートカットのようなものです。オブジェクトとは、MODx内のリソース・他サイトのページや画像などを含みます。基本的にはリンク先のオブジェクトへリダイレクトします。<p>';
$_lang['weblink_new'] = '新しいウェブリンク';

==> modx-2.1.3-pl-ja.zip: modx-2.1.3-pl-ja/core/lexicon/ja/resource.inc.php <==
<?php
/**
 * Resource Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['access'] = 'アクセス';
$_lang['cache_output'] = 'キャッシュ出力';
$_lang['changes'] = '変更';
$_lang['class_key'] = 'クラスキー';
$_lang['context'] = 'コンテキスト';
$_lang['createedit_document'] = 'ドキュメントの作成・編集';
$_lang['createedit_static'] = '静的リソースの作成・編集';
$_lang['createedit_symlink'] = 'シムリンクの作成・編集';
$_lang['createedit_weblink'] = 'ウェブリンクの作成・編集';
$_lang['document'] = 'ドキュメント';
$_lang['document_create'] = 'ドキュメントを作成';
$_lang['document_create_here'] = 'ここにドキュメントを作成';
$_lang['document_new'] = '新しいドキュメント';
$_lang['documents'] = 'ドキュメント';
$_lang['duplicate_uri_found'] = 'リソース [[+id]] はすでにURLとして [[+uri]] を使用しています。エイリアスまたはFreeze URIを入力し直してください。';
$_lang['empty_template'] = '(空)';
$_lang['general'] = '一般';
$_lang['markup'] = 'マークアップ/構造';
$_lang['none'] = 'なし';
$_lang['page_settings'] = 'ページ設定';
$_lang['preview'] = 'プレビュー';
$_lang['resource_access_message'] = 'このリソースが属するリソースグループを設定できます。';
$_lang['resource_add_children_access_denied'] = '現在のアカウントにはここにリソースを作成する権限がありません。';
$_lang['resource_alias'] = 'エイリアス';
$_lang['resource_alias_help'] = 'このリソースの別名。この名前はURL表現にも使用されます。<br /><br />http://example.com/alias<br /><br />フレンドリーURL設定が有効な場合のみ動作します。';
$_lang['resource_change_template_confirm'] = 'このテンプレートを変更しますか？ WARNING: This will save your prior changes to the change and reload the page; ensure you are ready to do so before proceeding. After the page has reloaded, you will need to save again when you are ready to save the Template change.';
$_lang['resource_cacheable'] = 'キャッシュ有効';
$_lang['resource_cacheable_help'] = '有効にすると、リソースはキャッシュに保存されます。';
$_lang['resource_cancel_dirty_confirm'] = '未確定の変更があります。本当にキャンセルしますか？';
$_lang['resource_class_key_help'] = 'これはリソースのクラスキーです。MODXのタイプで表示します。';
$_lang['resource_content'] = 'リソースコンテンツ';
$_lang['resource_contentdispo'] = 'コンテンツの渡し方';
$_lang['resource_contentdispo_help'] = 'このの項目を使用して、このリソースがブラウザでどのように扱われるかを指定します。「Attachment」を選択するとファイルのダウンロードとみなします。';
$_lang['resource_content_type'] = 'コンテンツタイプ';
$_lang['resource_content_type_help'] = 'このリソースのコンテンツタイプを設定します。どのコンテンツタイプを選択すればよいかが分からない場合は、「text/html」のままにして下さい。';
$_lang['resource_create_access_denied'] = '現在のアカウントにはリソースを作成する権限がありません。';
$_lang['resource_create_here'] = 'ここにリソースを作成する';
$_lang['resource_createdby'] = '作成者';
$_lang['resource_createdon'] = '作成日';
$_lang['resource_delete'] = '削除する';
$_lang['resource_delete_confirm'] = '本当にこのリソースを削除しますか？<br />サブリソースも同時に削除されます。';
$_lang['resource_description'] = '説明(Description)';
$_lang['resource_description_help'] = 'リソースの説明。検索エンジン対策などに。[[*description]]として呼び出します。';
$_lang['resource_duplicate'] = '複製を作る';
$_lang['resource_duplicate_confirm'] = '本当にこのリソースを複製しますか？サブリソースも複製されます。';
$_lang['resource_edit'] = '編集する';
$_lang['resource_editedby'] = '編集者';
$_lang['resource_editedon'] = '編集日';
$_lang['resource_err_change_parent_to_folder'] = 'リソースの親フォルダを変更中にエラーが発生しました。';
$_lang['resource_err_class'] = 'リソースは有効な [[+class]] ではありません。';
$_lang['resource_err_create'] = 'リソースの作成中にエラーが発生しました。';
$_lang['resource_err_delete'] = 'リソースの削除中にエラーが発生しました。';
$_lang['resource_err_delete_children'] = 'サブリソースを削除中にエラーが発生しました。';
$_lang['resource_err_delete_container_sitestart'] = '削除しようとしているリソースは、リソース [[+id]] を含むコンテナです。このリソースは「サイトスタート」として登録されているため、削除できません。他のリソースを「サイトスタート」に設定してからリトライしてください。';
$_lang['resource_err_delete_container_siteunavailable'] = '削除しようとしているリソースはリソース [[+id]] を含むフォルダーです。このリソースは、「メンテナンスモード用ページ」として登録されているため、削除できません。他のリソースを「メンテナンスモード用ページ」に設定してからリトライしてください。';
$_lang['resource_err_delete_sitestart'] = '「サイトスタート」のリソースであるため、削除できません';
$_lang['resource_err_delete_siteunavailable'] = '「メンテナンスモード用ページとして使用されているため、削除できません';
$_lang['resource_err_duplicate'] = 'リソースを複製中にエラーが発生しました。';
$_lang['resource_err_move_to_child'] = '自身のサブリソースには移動できません。';
$_lang['resource_err_move_sitestart'] = 'The resource is linked to the site_start variable and cannot be moved to another context!';
$_lang['resource_err_nf'] = 'リソースが見つかりませんでした。';
$_lang['resource_err_nfs'] = 'ID [[+id]] のリソースが見つかりません。';
$_lang['resource_err_ns'] = 'リソースが指定されていません。';
$_lang['resource_err_own_parent'] = 'リソースは自身の親にはなれません。';
$_lang['resource_err_publish'] = 'リソースの公開開始日時設定中にエラーが発生しました。';
$_lang['resource_err_new_parent_nf'] = 'ID [[+id]] の親リソースが見つかりません。';
$_lang['resource_err_remove'] = 'リソースの削除中にエラーが発生しました。';
$_lang['resource_err_save'] = 'リソースの保存中にエラーが発生しました。';
$_lang['resource_err_select_parent'] = '親リソースを選択して下さい。';
$_lang['resource_err_undelete'] = 'リソースの復活中にエラーが発生しました。';
$_lang['resource_err_undelete_children'] = 'サブリソースを復活中にエラーが発生しました。';
$_lang['resource_err_unpublish'] = 'リソースの公開終了日時設定中にエラーが発生しました。';
$_lang['resource_err_unpublish_sitestart'] = 'このリソースはトップページ(site_start)として設定されています。非公開に設定することはできません。';
$_lang['resource_err_unpublish_sitestart_dates'] = 'リソースはサイトスタート変数にリンクされていて、公開開始・終了の日付情報を保持することはできません';
$_lang['resource_folder'] = 'コンテナ属性';
$_lang['resource_folder_help'] = 'これにチェックを入れると、リソースは他のリソースのコンテナとして機能します。「コンテナ」はフォルダのようなもので、これだけがコンテンツを持つことができます。';
$_lang['resource_group_resource_err_ae'] = 'リソースは既にそのリソースグループに含まれます。';
$_lang['resource_group_resource_err_nf'] = 'リソースはそのリソースグループに含まれません。';
$_lang['resource_hide_from_menus'] = 'メニューに表示しない';
$_lang['resource_hide_from_menus_help'] = '有効にしたとき、リソースはウェブメニューの中で有効に<b>なりません</b>。いくつかのMenuBuilderではこのオプションを無視する可能性があることに注意してください。';
$_lang['resource_link_attributes'] = 'リンク属性';
$_lang['resource_link_attributes_help'] = 'このリソースのリンクの属性を指定します。例えば target= や rel= など。';
$_lang['resource_locked_by'] = '[[+user]] にロックされています。';
$_lang['resource_longtitle'] = '長いタイトル';
$_lang['resource_longtitle_help'] = '長いタイトルを指定します。[[*longtitle]]として呼び出します。';
$_lang['resource_menuindex'] = 'メニューインデックス';
$_lang['resource_menuindex_help'] = 'これは一覧の中でのリソースの順序です。それは通常、動的にリソースを表示する順序を指定するために使用されます。いくつかの設定ではこれを無視するかもしれません。';
$_lang['resource_menutitle'] = 'メニュータイトル';
$_lang['resource_menutitle_help'] = 'ナビゲーションのメニュー名に用いる想定の、短めのタイトルを指定します。[[*menutitle]]として呼び出します。';
$_lang['resource_new'] = '新しいリソース';
$_lang['resource_notcached'] = 'このリソースはまだキャッシュされていません。';
$_lang['resource_pagetitle'] = 'タイトル';
$_lang['resource_pagetitle_help'] = 'リソース名を指定します。バックスラッシュは使えません。[[*pagetitle]]として呼び出します。サイトツリーの表示が煩雑にならないよう、短めの名前をつけるとよいでしょう。長めのタイトルが必要な場合は「長いタイトル」をお使いください。';
$_lang['resource_parent'] = '親リソース';
$_lang['resource_parent_help'] = '親リソースのIDを設定します。';
$_lang['resource_parent_select_node'] = '左のリストからノードを選択して下さい。';
$_lang['resource_publish'] = '公開する';
$_lang['resource_publish_confirm'] = 'ここで公開すると、このリソースに設定されている公開日時情報が初期化されます。もし設定を維持したい場合はリソース編集画面を開いて必要に応じて編集してください。<br />続けますか？';
$_lang['resource_publishdate'] = '公開開始予定日時';
$_lang['resource_publishdate_help'] = '公開開始予定日時をセットすると、公開開始予定日時になるとすぐに公開されます。カレンダーアイコンをクリックし、日付を選択するか、自動的に公開開始されないように空白にしてください。';
$_lang['resource_published'] = '公開する';
$_lang['resource_published_help'] = '「公開する」のチェックを外すと、このリソースは非公開になります。';
$_lang['resource_publishedby'] = '公開者';
$_lang['resource_publishedon'] = '公開開始日時';
$_lang['resource_publishedon_help'] = 'リソースが公開開始された日時。';
$_lang['resource_refresh'] = 'ツリー表示を更新';
$_lang['resource_richtext'] = 'リッチテキスト';
$_lang['resource_richtext_help'] = '有効にすると、リソースの編集にリッチテキストエディタを使用できます。リソースにJavaScriptやフォームを含む場合は、リッチテキストエディタがスクリプトやタグを乱す可能性がありますので、このチェックをはずし、プレーンテキストモードで編集してください。';
$_lang['resource_searchable'] = '検索対象';
$_lang['resource_searchable_help'] = '有効にすると、リソースを検索することができます。また、この設定はスニペットで他の目的に使用することができます。';
$_lang['resource_settings'] = 'リソース設定';
$_lang['resource_status'] = 'ステータス';
$_lang['resource_status_help'] = '公開開始されている場合はリソースは保存された直後に一般の人に閲覧可能になります。それ以外の場合は、公開サイトからは見えません。';
$_lang['resource_summary'] = '要約(リード文)';
$_lang['resource_summary_help'] = 'リソースの簡単な概要。新着情報の一覧やRSSフィードなどで用いるとよいでしょう。';
$_lang['resource_syncsite'] = '更新時にキャッシュ削除';
$_lang['resource_syncsite_help'] = 'ここにチェックを入れると、リソースの保存時にキャッシュを初期化します。';
$_lang['resource_template'] = '使用テンプレート';
$_lang['resource_template_help'] = 'リソースで使用するテンプレートを設定します。';
$_lang['resource_undelete'] = '削除から復活';
$_lang['resource_unpublish'] = '非公開にする';
$_lang['resource_unpublish_confirm'] = 'ここで非公開にすると、このリソースに設定されている公開日時情報が初期化されます。もし設定を維持したい場合はリソースの編集画面を開いて必要に応じて編集してください。<br />続けますか？';
$_lang['resource_unpublishdate'] = '公開終了予定日時';
$_lang['resource_unpublishdate_help'] = '公開終了予定日時を設定すると、公開終了予定日時になるとすぐに公開が終了します。カレンダーアイコンをクリックし、日付を選択するか、自動的に公開終了にされないように空白にしてください。';
$_lang['resource_unpublished'] = '公開終了';
$_lang['resource_untitled'] = '無題のリソース';
$_lang['resource_uri'] = 'URI';
$_lang['resource_uri_help'] = 'The full relative URL for this Resource.';
$_lang['resource_uri_override'] = 'Freeze URI';
$_lang['resource_uri_override_help'] = 'Checking this will allow you to freeze the URI for this Resource at the value in the textbox below.';
$_lang['resource_with_id_not_found'] = 'リソースID %s が見つかりません。';
$_lang['resource_view'] = '詳細情報';
$_lang['show_sort_options'] = 'ソートオプションの表示';
$_lang['site_schedule'] = '公開状態の一覧';
$_lang['site_schedule_desc'] = '公開および公開終了の予定一覧';
$_lang['source'] = 'ソース';
$_lang['static_resource'] = '静的リソース';
$_lang['static_resource_create_here'] = 'ここに静的リソースを作成';
$_lang['static_resource_new'] = '新しい静的リソース';
$_lang['status'] = 'ステータス';
$_lang['symlink'] = 'シムリンク';
$_lang['symlink_create'] = 'シムリンクを作成';
$_lang['symlink_create_here'] = 'ここにシムリンクを作成';
$_lang['symlink_help'] = 'The address of the object you wish to reference with this Symlink. If you want to point to an existing MODX Resource, enter the ID here.';
$_lang['symlink_message'] = 'シムリンクは、他の任意のリソースのクローンです。クローン元の内容がそのまま表示されますが、URLはここで指定したものが反映されます。';
$_lang['symlink_new'] = '新しいシムリンク';
$_lang['template_variables'] = 'テンプレート変数';
$_lang['untitled_resource'] = '無題のリソース';
$_lang['weblink'] = 'ウェブリンク';
$_lang['weblink_create'] = 'ウェブリンクを作成';
$_lang['weblink_create_here'] = 'ここにウェブリンクを作成';
$_lang['weblink_help'] = 'このウェブリンクによって参照させたいオブジェクトのアドレスを設定します。';
$_lang['weblink_message'] = 'ウェブリンクは、インターネット上のあらゆるオブジェクトに対するショートカットのようなものです。オブジェクトとは、MODX内のリソース・他サイトのページや画像などを含みます。基本的にはリンク先のオブジェクトへリダイレクトします。<p>';
$_lang['weblink_new'] = '新しいウェブリンク';
